@@ -153,9 +153,18 @@ def get_file_in_time_range(input_args, **kwargs):
     Returns:
         _type_: _description_
     """
+
+    # if input_args.log_root_dir is None or empty, raise error
+    if not input_args.log_root_dir:
+        raise FileNotFoundError(f"--log_root_dir 不能为空")
+
     if "download_log" in kwargs and kwargs["download_log"]:
         return get_file_in_time_range_for_download(input_args.log_root_dir, input_args.time_range, parse(input_args.timestamp), **kwargs)
 
+    # if input_args.robot_id is empty or None, raise RuntimeError
+    if not input_args.robot_id:
+        raise RuntimeError("robot_id is empty")
+
     if input_args.prd_type == "sort":
         return get_file_in_time_range_sort(input_args.robot_id, input_args.log_root_dir, input_args.time_range, parse(input_args.timestamp))
 
