@@ -2,11 +2,13 @@
 
   example: src/pack_log.py --prd_type=sort --time_range=100  --timestamp="2022-09-13 17:55:00" --log_root_dir=/tmp/66log
 """
+from nis import cat
 from src.log_utility import *
 import argparse
 import tarfile
 import os
 from datetime import datetime
+from alive_progress import alive_bar
 
 OUTPUT_DIR = "/tmp/log_trans/"
 OUTPUT_FILE = f"{OUTPUT_DIR}log.tar.gz"
@@ -24,6 +26,7 @@ def init_input_args(sub_parser):
         help="希望抓取日志的有效时间范围：默认前后30分钟。截取的日志范围，距离时间点（--timestamp）前后多少分钟。",
         default=30,
         choices=range(1, 60),
+        metavar="[1 ~ 60]",
     )
     sub_parser.add_argument("--log_root_dir", help="log 文件的根目录", required=True)
     sub_parser.add_argument(
@@ -72,12 +75,18 @@ def pack_log(input_args):
         return
 
     print(f"totlal {len(log_files)} files, compress start ...")
-    with tarfile.open(input_args.output_file, "w:gz") as tar:
-        for log_file in log_files:
-            tar.add(log_file)
 
-    print("compress complete ...")
+    # terminal process bar for compress with alive-progress with IO info
+    with alive_bar(len(log_files)) as bar:
+        with tarfile.open(input_args.output_file, "w:gz") as tar:
+            for log_file in log_files:
+                try:
+                    tar.add(log_file)
+                except FileNotFoundError:
+                    print(f"file {log_file} is not exist")
+            bar()
 
+    print(f"compress complete, total {len(log_files)} files, output file: {input_args.output_file}")
 
 if __name__ == "__main__":
     parser = argparse.ArgumentParser(
